/* $Id: omega_catalog.h,v 1.2 2011/07/22 09:57:41 agabasch Exp $
 *
 * This file is part of the OMEGA Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * $Author: agabasch $
 * $Date: 2011/07/22 09:57:41 $
 * $Revision: 1.2 $
 * $Name: omega-1_0_2 $
 */

#ifndef OC_CATALOG_H
#define OC_CATALOG_H

/*-----------------------------------------------------------------------------
   								Includes
 -----------------------------------------------------------------------------*/

#include <cpl.h>

CPL_BEGIN_DECLS

#define omega_max(_x,_y) (_x > _y ? _x : _y)
#define omega_min(_x,_y) (_x < _y ? _x : _y)
#define NGRIDMAX 31
#define NX 2048
#define NY 4100


/**
 * @ingroup omega_catalog
 *
 * @brief
 *   Functions to handle catalogues and tables
 */

int omega_get_coverage(cpl_propertylist *plist, int fudge, cpl_matrix *from, double *ra1,
			   double *ra2, double *dec1, double *dec2);

cpl_table *omega_extract_stds(const char *pathname, cpl_vector *coords, int n);
int omega_matchstds(cpl_table *objtab, cpl_table *stdstab, float srad, cpl_table **outtab);
cpl_table *omega_get_usnoa_table(const cpl_frame *catalog, cpl_vector *coords, int *nstds);
cpl_table *omega_get_stds_table(const char *stdcat, cpl_vector *coords, int *nstds);
cpl_table * wcscor_matchstds(cpl_table *objtab, cpl_table *stdstab, float srad);

cpl_table *omega_filter_table_int(cpl_table *src, const char *col, cpl_table_select_operator operator,
		                         int value, int *nsrc);
cpl_table *omega_filter_table_double(cpl_table *src, const char *col, cpl_table_select_operator operator,
		                     double value, int *nsrc);
cpl_table *omega_filter_table_string(cpl_table *src, const char *col, cpl_table_select_operator operator,
		                     const char *value, int *nsrc);
cpl_table *omega_filter_table_float(cpl_table *src, const char *col, cpl_table_select_operator operator,
		                     float value, int *nsrc);
cpl_table *omega_science_catalogue(const char *sci, const char *conf, double zeropoint_final, cpl_parameterlist *pars);

CPL_END_DECLS

#endif
