/* $Id: omega_dfs.h,v 1.5 2012/08/30 06:44:50 agabasch Exp $
 *
 * This file is part of the OMEGA Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * $Author: agabasch $
 * $Date: 2012/08/30 06:44:50 $
 * $Revision: 1.5 $
 * $Name: omega-1_0_2 $
 */

#ifndef OMEGA_DFS_H
#define OMEGA_DFS_H

#include <cpl.h>
#include <cpl_plot.h>

/*-----------------------------------------------------------------------------
								Define
 -----------------------------------------------------------------------------*/
/*General definitions*/
#define BIAS	160
#define BITPIX	CPL_BPP_IEEE_FLOAT
#define GAIN    2.0
#define PI 3.1415926535897932384626433832795
#define SEXTRACTOR_ARGC 30
#define MAXPATH 120
#define SQRT2   1.4142136
/* NOTE: Once CPL recalculates CHECKSUM and DATASUM, they should be
 * removed from the list below
 */
#define REM_EXT_KEYS "^(ESO OBS |ESO TEL |ESO INS |ORIGIN|TELESCOPE|INSTRUME|OBJECT|RA|DEC|EPOCH|EQUINOX|" \
        "CHECKSUM|DATASUM|DATAMD5|RADECSYS|DATE-OBS|MJD-OBS|UTC|LST|PI-COI|OBSERVER|PIPEFILE).*$"

#define REM_PRIM_KEYS "^(CHECKSUM|DATASUM)$"
#define TIMEOUT 60

#define WCS_KEYS "WCSAXES|WCSNAME|(PC|CD|PV|PS)[0-9]+_[0-9]+|" \
                                "C(RVAL|RPIX|DELT|TYPE|UNIT|RDER|SYER)[0-9]+"

/* Define here the PRO.CATG keywords */
/*#define RRRECIPE_XXX_PROCATG            "THE_PRO_CATG_VALUE"*/
#define BCKG_PROCATG		"BACKGROUND"
#define BPM_PROCATG	        "BAD_PIXELS_MAP"

/* Science */
#define STACK_PROCATG		"STACK_SCIENCE"
#define CONF_PROCATG		"CONF_MAP_SCIENCE"
#define CAT_PROCATG			"SCIENCE_CATALOGUE"
#define SIMPLE_STARE		"SIMPLE_SCIENCE"
#define SIMPLE_JITTER		"SIMPLE_JITTER"
#define SIMPLE_DITHER	    "SIMPLE_DITHER"
#define SIMPLE_OFFSET	    "SIMPLE_OFFSET"
#define SIMPLE_MASK         "SIMPLE_MASK"

/* Dome flat recipe */
#define MDOME_PROCATG		"MASTER_FLAT_DOME"
#define CPM_PROCATG		"COLD_PIXELS_MAP"

/* shutter recipe */
#define SHUTTER_PROCATG		"SHUTTER_TEST"

/* Gain recipes */
#define GAIN_PROCATG            "GAIN"
#define LG_PROCATG            "GAIN_LINEARITY"
#define CUBE_PROCATG     "LIN_COEFFS_CUBE"
#define LBPM_PROCATG    "NON_LINEAR_BPM"
#define GDIFF_PROCATG  "GAIN_DIFFERENCE"
#define ACORR_PROCATG  "GAIN_AUTOCORR"

/* Bias recipe */
#define HPM_PROCATG		"HOT_PIXELS_MAP"
#define MBIAS_PROCATG		"MASTER_BIAS"

#define ILLUM_PROCATG		"ILLUMINATION"

/* Quick check recipe */
#define LTEST_PROCATG           "LIFETEST_CHECK"

/* Master flat recipe */
#define MFLAT_PROCATG		"MASTER_FLAT"
#define MTWIL_PROCATG		"MASTER_FLAT_TWILIGHT"

/* Standard star recipe */
#define STD_PROCATG		"REDUCED_STD"
#define ZP_PROCATG		"ZEROPOINTS"
#define PHOT_PROCATG	"PHOTOMETRIC_TABLE"

/* dark current recipe */
#define OMEGA_CALIB_DARK         "DARK_CURRENT"
#define DARK_PROCATG            "MEAN_DARK"

/* Others */
#define FRINGES_PROCATG		"FRINGES_FLAT"
#define NSKY_PROCATG		"MASTER_NIGHT_SKY_FLAT"
#define SATEMAP_PROCATG		"SATELLITES_MAP"
#define SATUMAP_PROCATG		"SATURATED_PIXELS_MAP"
#define COSMAP_PROCATG		"COSMIC_RAYS_MAP"

/* Define here the DO.CATG keywords (SOF tags)*/
#define DARK_RAW         "DARK"
#define STARE_RAW        "STARE"
#define DITHER_RAW		"DITHER"
#define OFFSET_RAW      "OFFSET"
#define FRINGES_RAW       "FRINGES"
#define GAIN_FLAT        "FLAT_DOME_DETGAIN"
#define GAIN_DARK        "DARK_DETGAIN"
#define JITTER_RAW		"JITTER"
#define LIFETEST_RAW     "DOME_LIFETEST"
#define MBIAS_RAW        "BIAS"
#define MDOME_RAW        "DOME_FLAT"
#define MTWIL_RAW        "TWILIGHT_FLAT"
#define RNOISE_RAW       "BIAS_READNOISE"
#define STD_RAW			"STD_ZEROPOINT"
#define NSKY_RAW        "NIGHTSKY_FLAT"
#define SHUTTER_RAW     "DOME_SHUTTERTEST"

/* Static calibration frames */
#define OMEGA_CALIB_EXTCUR	"EXTINCTION_CURVE"
#define OMEGA_CALIB_MONIT        "MONITOR_REPORT"
#define OMEGA_CALIB_REFSTAR      "REFERENCE_STAR_CATALOG"
#define OMEGA_CALIB_TWIL         "MASTER_FLAT_TWILIGHT"
#define OMEGA_CALIB_ZP         	"ZEROPOINTS"
#define OMEGA_USNOA2             "MASTER_USNOA2_CATALOGUE"
#define OMEGA_CALIB_COLTERMS     "COLOUR_TERMS"
#define OMEGA_CALIB_BIAS         "MASTER_BIAS"
#define OMEGA_CALIB_BPM         	"BAD_PIXELS_MAP"
#define OMEGA_CALIB_CPM         	"COLD_PIXELS_MAP"
#define OMEGA_CALIB_DOME         "MASTER_FLAT_DOME"
#define OMEGA_CALIB_FLAT         "MASTER_FLAT"
#define OMEGA_CALIB_FRINGE       "MASTER_FLAT_FRINGE"
#define OMEGA_CALIB_GAIN		"GAIN_LINEARITY"
#define OMEGA_CALIB_HPM         	"HOT_PIXELS_MAP"
#define OMEGA_CALIB_ILLFIT       "ILLUM_FIT_PAR"
#define OMEGA_CALIB_ILLUM        "ILLUM_CORR"
#define OMEGA_CALIB_NSKY         "MASTER_FLAT_NIGHT_SKY"
#define OMEGA_CALIB_RDNOISE      "READNOISE_ADU"

/* Define here the tags for the REFERENCE frames */
#define REFBIAS                "REFERENCE_BIAS"
#define REFDOME                "REFERENCE_DOME"
#define REFTWIL                "REFERENCE_TWILIGHT"
#define REFMFLAT               "REFERENCE_MFLAT"


/* Define here other PRO keywords??*/
#define OMEGA_PRODID     "ESO-2P2-DIC.OMEGA-ICS v0.0" /*FIXME*/

/*-----------------------------------------------------------------------------
                        Static variables
 -----------------------------------------------------------------------------*/

static const char PIPEID[] = PACKAGE "/" PACKAGE_VERSION;
static const char DICID[] = "PRO-1.15";

/*-----------------------------------------------------------------------------
				Functions prototypes
 -----------------------------------------------------------------------------*/

int oc_dfs_set_groups(cpl_frameset *) ;

#endif
