/* $Id: omega_fits.h,v 1.1.1.1 2011/03/16 11:59:34 agabasch Exp $
 *
 * This file is part of the OMEGA Pipeline
 * Copyright (C) 2005 Cambridge Astronomy Survey Unit
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * $Author: agabasch $
 * $Date: 2011/03/16 11:59:34 $
 * $Revision: 1.1.1.1 $
 * $Name: omega-1_0_2 $
 */


/* Includes */

#ifndef OMEGA_FITS_H
#define OMEGA_FITS_H

#include <cpl.h>

/* OMEGA FITS structure.  */

typedef struct {
	cpl_frame        *frame;
    cpl_image        *image;
    cpl_propertylist *phu;
    cpl_propertylist *ehu;
    char             *fname;
    char             *extname;
    char             *fullname;
    int              extnum;
    int              status;
} omega_fits;

/* OMEGA_FITS methods prototypes */

extern omega_fits *omega_fits_load(const cpl_frame *frame, cpl_type type, int extnum);
extern omega_fits *omega_fits_duplicate(omega_fits *in);
extern omega_fits **omega_fits_load_list(const cpl_frameset *f, cpl_type type,
					int exten);
extern void omega_fits_delete(omega_fits *p);
extern void omega_fits_delete_list(omega_fits **p, int n);
extern cpl_frame *omega_fits_get_frame(omega_fits *p);
extern cpl_image *omega_fits_get_image(omega_fits *p);
extern int omega_fits_get_extnum(omega_fits *p);
extern char *omega_fits_get_filename(omega_fits *p);
extern cpl_propertylist *omega_fits_get_phu(omega_fits *p);
extern cpl_propertylist *omega_fits_get_ehu(omega_fits *p);
extern char *omega_fits_get_extname(omega_fits *p);
extern char *omega_fits_get_fullname(omega_fits *p);
extern int omega_fits_get_status(omega_fits *p);
extern int omega_fits_set_error(omega_fits *p, int status);
extern void omega_fits_set_filename(omega_fits *p, char *fname);
extern omega_fits *omega_fits_wrap(cpl_image *im, omega_fits *model,
				  cpl_propertylist *phu,
				  cpl_propertylist *ehu);
#endif
