/* $Id: omega_utils.h,v 1.5 2012/01/12 12:05:09 agabasch Exp $
 *
 * This file is part of the OMEGA Pipeline
 * Copyright (C) 2002,2003 European Southern Observatory
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/*
 * $Author: agabasch $
 * $Date: 2012/01/12 12:05:09 $
 * $Revision: 1.5 $
 * $Name: omega-1_0_2 $
 */

#ifndef OC_UTILS_H
#define OC_UTILS_H

/*-----------------------------------------------------------------------------
   								Includes
 -----------------------------------------------------------------------------*/

#include <cpl.h>
#include "omega_dfs.h"
#include "omega_fits.h"

#define VIR_OK 0
#define VIR_WARN 1
#define VIR_FATAL 2

#if defined CPL_VERSION_CODE && CPL_VERSION_CODE <= CPL_VERSION(5, 5, 0)
typedef int cpl_size; /* The type as is was up to CPL 5.3 */
#define CPL_SIZE_FORMAT "d"
#endif

/* Macros for freeing up space */

#define freespace(_p) if (_p != NULL) {cpl_free(_p); _p = NULL;}
#define freeframe(_p) if (_p != NULL) {cpl_frame_delete(_p); _p = NULL;}
#define freeimage(_p) if (_p != NULL) {cpl_image_delete(_p); _p = NULL;}
#define freeilist(_p) if (_p != NULL) {cpl_imagelist_delete(_p); _p = NULL;}
#define freeframeset(_p) if (_p != NULL) {cpl_frameset_delete(_p); _p = NULL;}
#define freetable(_p) if (_p != NULL) {cpl_table_delete(_p); _p = NULL;}
#define freeplist(_p) if (_p != NULL) {cpl_propertylist_delete(_p); _p = NULL;}
#define freestats(_p) if (_p != NULL) {cpl_stats_delete(_p); _p = NULL;}
#define freefits(_p) if (_p != NULL) {omega_fits_delete(_p); _p = NULL;}
#define freelfits(_p,_n) if (_p != NULL) {omega_fits_delete_list(_p,_n); _p = NULL;}
#define freetfits(_p) if (_p != NULL) {omega_tfits_delete(_p); _p = NULL;}
#define freemask(_p) if (_p != NULL) {cpl_mask_delete(_p); _p = NULL;}
#define freematrix(_p) if (_p != NULL) {cpl_matrix_delete(_p); _p = NULL;}
#define freevector(_p) if (_p != NULL) {cpl_vector_delete(_p); _p = NULL;}
#define freebivector(_p) if (_p != NULL) {cpl_bivector_delete(_p); _p = NULL;}
#define freematrix(_p) if (_p != NULL) {cpl_matrix_delete(_p); _p = NULL;}
#define freewcs(_p) if (_p != NULL) {cpl_wcs_delete(_p); _p = NULL;}
#define freearray(_p) if (_p != NULL) {cpl_array_delete(_p); _p = NULL;}

/* Prototypes */
const char * omega_get_license(void) ;
FILE 	   * oc_paf_print_header(
        char    *,
        char    *,
        char    *);

char * omega_get_root_name(const char * filename);
extern int omega_compare_tags(const cpl_frame *frame1, const cpl_frame *frame2);
extern void omega_exten_range(int inexten, int *out1, int *out2);
extern void omega_extensions(const cpl_frame *frame, int inexten, int *out1, int *out2);
extern cpl_frameset *omega_frameset_subgroup(cpl_frameset *frameset,
					      cpl_size *labels, cpl_size nlab,
					      const char *tag);
int omega_compare_reference(const cpl_image *master, const cpl_frame *refframe,
                           int ext, cpl_stats **diffstats);

char * omega_get_pathname(const char * filename);
cpl_frame *omega_product_frame(const char *filename, const char *tag, cpl_frame_type type);

int omega_save_dummy(cpl_frameset *set, cpl_parameterlist *parlist,cpl_frame_type type,
                           cpl_type_bpp bitpix, const char *outfile, const cpl_propertylist *plist,
                           const char *recipe, cpl_frame *product_frame);

int omega_save_primary(cpl_frameset *set, const cpl_parameterlist *parlist,
                     const char *outfile, const char *recipe, const cpl_propertylist *plist,
                     cpl_frame *product_frame, const cpl_frame *inherit);

cpl_image *omega_smooth_image(cpl_image *in, int size);
char *omega_create_name(const char *instrument, const char *name, const char *suffix);
int omega_biascor(cpl_image *image, const cpl_image *bias);
const char * omega_get_extension_chipid(int ext);
int omega_get_chip_orientation(int ext);
int omega_save_image(const cpl_image *img,cpl_frameset *set,const cpl_parameterlist *pars,
		cpl_propertylist *alist, const cpl_propertylist *qclist,cpl_type_bpp bpp,
		const char *name, const char *recipe, cpl_frame *frame,
		const cpl_frame *inherit, int isfirst);

int omega_save_table(const cpl_table *tbl,cpl_frameset *set,const cpl_parameterlist *pars,
		cpl_propertylist *alist, const cpl_propertylist *qclist,const char *name,
		const char *recipe, cpl_frame *frame,const cpl_frame *inherit, int isfirst);

int omega_save_fits(omega_fits *scifits,cpl_frameset *set, const cpl_parameterlist *pars,
							const cpl_propertylist *qclist, cpl_type_bpp bpp,const char *name,
							const char *recipe,cpl_frame *product_frame, const cpl_frame *inherit,
							const int isfirst);
cpl_error_code omega_get_pixelscale(cpl_propertylist *plist,
		double * pixscale_x, double * pixscale_y);

cpl_error_code omega_get_wcsshift(cpl_propertylist * wcslist1,
		cpl_propertylist * wcslist2, double * xshift, double * yshift);

#endif
